ytree\.tree\_farm\.tree\_farm\.TreeFarm\.set\_ancestry\_short
=============================================================

.. currentmodule:: ytree.tree_farm.tree_farm

.. automethod:: TreeFarm.set_ancestry_short